{% extends "@SerenityAdmin/layout/base.html.twig" %}
{% block title %}

{% endblock %}
{% block h2 %}Tenants{% endblock %}
{% block main %}
    <div class="h-full rounded-lg bg-white p-8 shadow-lg dark:bg-gray-800">
        <div class="relative">
            <twig:SerenityAdmin:Crud
                class='Serenity\\SaasBundle\\Entity\\Tenant'
                searchType="Serenity\\SaasBundle\\Form\\Type\\TenantSearchType"
                searchClass="Serenity\\SaasBundle\\DTO\\TenantSearchDTO"
                disabledNewIfEmpty="{{ true }}">
                <twig:block name="template">
                    {{ include("@SerenitySaas/layout/admin/crud/tenants.html.twig") }}
                </twig:block>
            </twig:SerenityAdmin:Crud>
        </div>
    </div>
{% endblock %}
