{% extends '@SerenityAdmin/layout/base_blank.html.twig' %}
{% block navbar %}

{% endblock %}
{% block main %}
<div
  class="dark:bg-opacity-40 relative flex h-full grow flex-col bg-gray-100 py-12 dark:bg-gray-900">
  <div class="container mx-auto px-4 xl:max-w-6xl">
    <div class="-mx-4 flex flex-row flex-wrap justify-center">
      <div class="w-full max-w-full px-6 sm:px-12 md:w-2/3 lg:w-1/2">
        <div class="rounded-lg bg-white p-6 shadow-xl sm:px-12 sm:py-8 dark:bg-gray-800">
          {{ component('SerenitySaas:SelectProject') }}
        </div>
      </div>
    </div>
  </div>
</div>
{% endblock %}
