<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\SaasBundle\Seed;

use Serenity\CoreBundle\Seed\SeedPayload;
use Serenity\CoreBundle\Seed\SeedScopeProviderInterface;
use Serenity\SaasBundle\Doctrine\Repository\ProjectRepository;

final readonly class ProjectSeedScopeProvider implements SeedScopeProviderInterface
{
    public function __construct(private ProjectRepository $projectRepository)
    {
    }

    public function iterateForSeeding(SeedPayload $seedPayload): \Traversable
    {
        return $this->projectRepository->iterateForSeeding($seedPayload);
    }
}
